@@ -615,6 +615,166 @@ class CartesMembre(EtiquetteBase):
         self.drawSignature()
         return
 
+class CartonsJaunes(EtiquetteBase):
+    """
+    Implémentation de la structure de données spécifique aux cartes de membre
+    pour la coopérative du lycée Jean Bart. Les paramètres
+    du constructeur sont :
+    @param eleve une instance de la classe models.Eleves
+    """
+    specs = labels.Specification(
+        210, 297,                              # format A4
+        2, 3,                                  # 2 colonnes, 3 lignes
+        105, 99,                               # largeur, hauteur de l'étiquette
+        corner_radius=2,                       # arrondi
+        left_margin=0, right_margin=0,         # marges gauche et droite
+        top_margin=0,                          # marge en haut
+        left_padding=8,                        # espacement intérieur
+        right_padding=8,                       # 
+        top_padding=8,                         #
+        bottom_padding=8,                      #
+        row_gap=0                              # espace entre lignes
+    )
+
+    def __init__(self):
+        EtiquetteBase.__init__(self)
+        self.pylabel = None # instance de pylabel
+        self.w = None       # sa largeur, en points
+        self.h = None       # sa hauteur, en points
+        return
+
+    def drawEts(self, x='center', y=75):
+        """
+        Inscrit le nom de l'établissement dans un pylabel ;
+        attention, ici l'unité est le point typographique ; 1pt = 0.3528 mm
+        @param x l'abscisse de la chaîne à tracer ("center" par défaut)
+        @param y l'ordonnée de la chaîne à tracer (75 mm par défaut)
+        """
+        s = self.string("Lycée Jean Bart -- Dunkerque", fontSize=19)
+        self.adjustXY(s, x, y)
+        self.pylabel.add(s)
+        return
+
+    def drawTitle(self, x="center", y = 69):
+        """
+        Inscrit le titre 
+        @param x l'abscisse de la chaîne à tracer ("center" par défaut)
+        @param y l'ordonnée de la chaîne à tracer (70 mm par défaut)
+        """
+        classe = ".........."
+        s = self.string(
+            "Coopérative Scolaire      Classe : {classe}".format(classe=classe),
+            fontSize=12)
+        self.adjustXY(s, x, y)
+        self.pylabel.add(s)
+        return
+
+    def drawMembre(self, x="center", y=63):
+        """
+        Inscrit les données du membre
+        @param x l'abscisse de la chaîne à tracer ("center" par défaut)
+        @param y l'ordonnée de la chaîne à tracer (60 mm par défaut)
+        """
+        no = ".........."
+        s = self.string("Suivi de caution N° : {no}".format(no=no), fontSize=12)
+        self.adjustXY(s, x, y)
+        self.pylabel.add(s)
+        return
+
+    def drawNomPrenom(self, x="center", y=55):
+        """
+        Donne le nom du logiciel générateur et sa version. La taille
+        de la fonte sera 20 tant que la longueur de NomPrenomEleve ne
+        dépasse pas 20 caractères, et elle diminue après ça.
+        @param x l'abscisse de la chaîne à tracer ("center" par défaut)
+        @param y l'ordonnée de la chaîne à tracer (50 mm par défaut)
+        """
+        s = self.string("Nom : .........................", fontSize=20)
+        self.adjustXY(s, x, y)
+        self.pylabel.add(s)
+        return
+    
+    def drawSuivi(self, x=5, y=48):
+        # une ligne
+        p = shapes.PolyLine(
+            [mm2pt(v) for v in
+             [x, y, x+80, y]],
+            strokeWidth = 0.2,
+            strokeColor = toColor("rgb(0,0,0)"),
+        )
+        self.pylabel.add(p)
+        # lignes des livres
+        s = self.string(
+            "Livres non rendus : " + \
+            "...................................",
+            fontSize=12)
+        self.adjustXY(s, x, y-6)
+        self.pylabel.add(s)
+        s = self.string(
+            "...................................................................",
+            fontSize=12)
+        self.adjustXY(s, x, y-12)
+        self.pylabel.add(s)
+        # ligne de caution
+        s = self.string(
+            "Caution rendue : .............. €",
+            fontSize=12)
+        self.adjustXY(s, x, y-18)
+        self.pylabel.add(s)
+        # ligne des cartes d'identité
+        s = self.string(
+            "☐ CNI ☐ C. Bus ☐ Badge ☐ autre",
+            fontSize=10)
+        self.adjustXY(s, x, y-24)
+        self.pylabel.add(s)
+        # ligne du chèque
+        s = self.string(
+            "Chèque : ☐ guichet ☐ courrier",
+            fontSize=12)
+        self.adjustXY(s, x, y-30)
+        self.pylabel.add(s)
+        #Lignes date et ordre
+        s = self.string(
+            "Date, ordre : ............................",
+            fontSize=12)
+        self.adjustXY(s, x, y-36)
+        self.pylabel.add(s)
+        s = self.string(
+            "................................................",
+            fontSize=12)
+        self.adjustXY(s, x, y-42)
+        self.pylabel.add(s)
+        return
+    
+    def drawSignature(self, x=65, y=30):
+        s = self.string(
+            "Signature :",
+            fontSize=8)
+        self.adjustXY(s, x, y)
+        self.pylabel.add(s)
+        p = shapes.PolyLine(
+            [mm2pt(v) for v in
+             [x-1, y+5, x+21, y+5, x+21, y-25, x-1, y-25, x-1, y+5]],
+            strokeWidth = 0.1,
+            strokeColor = toColor("rgb(0,0,0)"),
+        )
+        self.pylabel.add(p)
+        return
+
+    def make_label(self,label, w, h):
+        """
+        Enchaîne toutes les étapes de création de l'étiquette, pour
+        la bibliothèque pylabels.
+        """
+        self.pylabel, self.w, self.h = label, w, h
+        self.drawEts()
+        self.drawTitle()
+        self.drawMembre()
+        self.drawNomPrenom()
+        self.drawSuivi()
+        self.drawSignature()
+        return
+
 class Suivi(EtiquetteBase):
     """
     Implémentation de la structure de données spécifique aux cartes de membre
