@@ -21,6 +21,7 @@
 from django.urls import path, re_path
 from . import views
 from . import views_download
+from . import views_graph
 from. import odfviews
 from . import views_stats
 from . import ajaxviews
@@ -98,6 +99,8 @@ urlpatterns = [
          name='cartes_membres_print_verso'),
     path('cartes_membres_print_verso_go', ajaxviews.cartes_membres_print_verso_go,
          name='cartes_membres_print_verso_go'),
+    path('cartons_jaunes_go', ajaxviews.cartons_jaunes_go,
+         name='cartons_jaunes_go'),
     path('fiches_suivi_print_go', ajaxviews.fiches_suivi_print_go,
          name='fiches_suivi_print_go'),
     path('retours', views.retours, name='retours'),
@@ -257,6 +260,17 @@ urlpatterns = [
     path('action_courrier', views.action_courrier, name='action_courrier'),
     path('action_courrier_go', ajaxviews.action_courrier_go,
          name='action_courrier_go'),
-    path('essai_svg', views.essai_svg,
-         name='essai_svg'),
+    path('essai_svg', views_graph.essai_svg, name='essai_svg'),
+    path('svg_from_dot', views_graph.svg_from_dot, name='svg_from_dot'),
+    path('rembourser', ajaxviews.rembourser, name='rembourser'),
+    path('rembourser_go', ajaxviews.rembourser_go, name='rembourser_go'),
+    path('digraphe_select', views_graph.digraphe_select, name='digraphe_select'),
+    path('update_digraphs', ajaxviews.update_digraphs, name='update_digraphs'),
+    path('test_selector', ajaxviews.test_selector, name='test_selector'),
+    path('lob', ajaxviews.lob, name='lob'),
+    path('dot_to_svg', ajaxviews.dot_to_svg, name='dot_to_svg'),
+    path('new_digraph', ajaxviews.new_digraph, name='new_digraph'),
+    path('del_digraph', ajaxviews.del_digraph, name='del_digraph'),
+    path('del_digraphe_select', ajaxviews.del_digraphe_select, name='del_digraphe_select'),
+    path('mv_digraphe_select', ajaxviews.mv_digraphe_select, name='mv_digraphe_select'),
 ]
