@@ -28,9 +28,7 @@ from django.utils.translation import gettext
 from django.utils.translation import activate, get_language_info
 
 from .views_common import render_common
-# from .views_download import *
-# from .views_stats import *
-# from .odfviews import *
+
 from .models import Eleves, Materiel, LivreSupplement, Jeton, Inventaire, \
     Courriers, Classes, les_modeles, modeles_ordre, ETAT_MATERIEL_CHOIX, \
     Parametres, Prets, Niveaux, NOCLASS, Disciplines, Filieres, Series, \
@@ -156,9 +154,13 @@ def stats(request):
     """
     ladate = date.today()
     classes = list(Classes.classes_importantes())
+    manuels_utilises = []
     for c in classes:
-        c.membres = len(Eleves.avec_prets_en_cours(classe=c.libelle))
+        c.membres = len(Eleves.membres(classe=c.libelle))
         c.membres_pc = round(100 * c.membres / c.compte)
+        titres = set((p.inventaire.materiel.titre for p in Prets.objects.filter(eleve__classe = c)))
+        titres = sorted(list(titres))
+        manuels_utilises.append((c.libelle, len(titres), titres))
     manuel_catalogue = Materiel.objects.all().order_by("titre")
 
     class GlobalLivre:
@@ -201,8 +203,8 @@ format(**self.__dict__)
                 n = len(Inventaire.objects.filter(materiel = m))
                 volumes[key].add(n, m)
                 total.add(n,m)
-    membres = Eleves.avec_prets_en_cours()
-    livres_par_eleves = [e.prets_en_cours for e in membres]
+    membres = Eleves.membres()
+    livres_par_eleves = [e.prets_count for e in membres]
     histogramme_lpe = svg_histogram(
         livres_par_eleves,
         _("Répartition des nombres de livres pour chaque élève"),
@@ -231,6 +233,7 @@ format(**self.__dict__)
         "histogramme_lpe": mark_safe(histogramme_lpe),
         "graphique_prets": mark_safe(graphique_prets),
         "graphique_retours": mark_safe(graphique_retours),
+        "manuels_utilises": manuels_utilises,
     })
 
 @ensure_csrf_cookie
@@ -776,8 +779,12 @@ def retours(request):
     """
     Page de retour des livres
     les paramètres du POST sont éventuellement nomprenom et codelivre.
+    le paramètre nomprenom peut aussi venir d'un GET
     """
     nomprenom = request.POST.get("nomprenom", "")
+    alt = request.GET.get("nomprenom", "")
+    if alt:
+        nomprenom = alt
     livre = request.POST.get("livre", "")
     return render_common(
         request,'gestion/retours.html',
@@ -1031,14 +1038,30 @@ def print_etat_classe(request):
     """
     classe = request.POST.get("classe")
     date = datetime.now().strftime("%Y-%m-%d")
-    eleves = Eleves.objects.filter(Lib_Structure = classe).order_by('NomPrenomEleve')
+    eleves = Eleves.objects.filter(Lib_Structure = classe). \
+        order_by('NomPrenomEleve').annotate(
+            prets_en_cours = Count(
+                'prets',
+                filter = ~Q(prets__date_retour__gt = DATE111) & \
+                Q(prets__inventaire__paye__isnull = True)
+            )
+        )
+    livres_par_eleves = [e.prets_en_cours for e in eleves]
+    histogramme_lpe = svg_histogram(
+        livres_par_eleves,
+        _("Répartition des nombres de livres dus"),
+        _("livres"),
+        bins = [0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16],
+    )
     return render(
         request,
         "gestion/print_etat_classe.html",
         {
             "classe": classe,
             "date": date,
-            "eleves": OrderedDict( ((e, ("doit" not in e.doit)) for e in eleves) )
+            "eleves": OrderedDict(
+                ((e, ("doit" not in e.doit)) for e in eleves) ),
+            "histogramme_lpe": mark_safe(histogramme_lpe),
         },
     )
     
@@ -1511,14 +1534,6 @@ def eleves_plus_n(request, niveau, nombre):
     elif niveau == "terminales":
         debut = "T"
         n = "terminale"
-    """
-    eleves = Eleves.objects.filter(classe__libelle__startswith = debut).\
-        order_by("classe__libelle", "sans_accent")
-    plus_n = {
-        e: len(Prets.faits_a(e)) for e in eleves if \
-           len(Prets.faits_a(e)) > int(nombre)
-    }
-    """
     plus_n = {
         e: len(Prets.faits_a(e)) for e in \
         Eleves.avec_prets_qs(int(nombre)).\
@@ -1606,15 +1621,3 @@ def action_courrier(request):
             "colonnes": list(range(1, 1+3)),
         })
 
-    
-def essai_svg(request):
-    """
-    page expérimentale pour bricoler des graphes de dépendances
-    """
-    return render_common(
-        request,
-        'gestion/essai_svg.html',
-        _("essai SVG"),
-        {
-            "aide": "",
-        })
